@@ -3,7 +3,7 @@ import uuid
 from psycopg import OperationalError
 from psycopg_pool import ConnectionPool
 import queue
-from psycopg.errors import ProgrammingError, InvalidParameterValue, UndefinedFunction
+from psycopg.errors import ProgrammingError, InvalidParameterValue, UndefinedFunction, InternalError
 import threading
 import traceback
 from jaaql.constants import ERR__invalid_token
@@ -31,6 +31,14 @@ class DBPGInterface(DBInterface):
     HOST_POOLS = {}
     HOST_POOLS_QUEUES = {}
 
+    @staticmethod
+    def close_all_pools():
+        for _, user_pool_dict in DBPGInterface.HOST_POOLS.items():
+            for _, pool in user_pool_dict.items():
+                pool.close()
+        DBPGInterface.HOST_POOLS = {}
+        DBPGInterface.HOST_POOLS_QUEUES = {}
+
     @staticmethod
     def put_conn_threaded(username: str, db_name: str, the_queue: queue.Queue):
         while True:
@@ -114,6 +122,12 @@ class DBPGInterface(DBInterface):
                     if self.role is not None:
                         try:
                             cursor.execute("SELECT jaaql__set_session_authorization('" + self.role + "', '" + conn.jaaql_reset_key + "');")
+                        except InternalError as ex:
+                            if str(ex).startswith("role \"") and str(ex).endswith("\" does not exist"):
+                                raise HttpStatusException(ERR__invalid_token, HTTPStatus.UNAUTHORIZED)
+                            else:
+                                traceback.print_exc()
+                                raise ex
                         except UndefinedFunction:
                             raise HttpStatusException("Database '%s' has not been configured for usage with JAAQL. Please ask the dba to run 'configure_database_for_use_with_jaaql' from the jaaql database" % self.db_name)
                     if self.sub_role is not None:
