@@ -1,6 +1,5 @@
 from jaaql.openapi.swagger_documentation import *
 from jaaql.constants import *
-from jaaql.documentation.documentation_shared import rename_arg, ARG_RES__application, ARG_RES__configuration
 
 TITLE = "JAAQL Internal API"
 DESCRIPTION = "Collection of methods in the JAAQL internal API"
@@ -14,21 +13,6 @@ ARG_RES__install_key = SwaggerArgumentResponse(
     required=True
 )
 
-ARG_RES__uninstall_key = rename_arg(ARG_RES__install_key, KEY__uninstall_key, ARG_RES__install_key.description.replace("INSTALL", "UNINSTALL"))
-
-DOCUMENTATION__canned_queries = SwaggerDocumentation(
-    tags="Application",
-    methods=SwaggerMethod(
-        name="Refresh Canned Queries",
-        description="Refreshes the application configuration canned queries.",
-        method=REST__POST,
-        arguments=[
-            ARG_RES__application,
-            ARG_RES__configuration
-        ]
-    )
-)
-
 DOCUMENTATION__install = SwaggerDocumentation(
     tags="Installation",
     security=False,  # This method is not secured as the system is not setup yet. It uses a OTP token system via logs
@@ -84,25 +68,6 @@ DOCUMENTATION__install = SwaggerDocumentation(
     )
 )
 
-DOCUMENTATION__uninstall = SwaggerDocumentation(
-    tags="Installation",
-    security=False,  # Would not matter which user uses it, needs root db credentials
-    methods=SwaggerMethod(
-        name="Uninstall JAAQL",
-        description="Uninstalls the JAAQL system",
-        method=REST__POST,
-        body=[
-            SwaggerArgumentResponse(
-                name=KEY__db_super_user_password,
-                description="The password for the database super user account",
-                example=["123456"],
-                arg_type=str
-            ),
-            ARG_RES__uninstall_key
-        ]
-    )
-)
-
 DOCUMENTATION__is_installed = SwaggerDocumentation(
     tags="Installation",
     security=False,
@@ -121,9 +86,6 @@ DOCUMENTATION__is_installed = SwaggerDocumentation(
     )
 )
 
-# Not unused. Used to generate html files
-from jaaql.documentation.documentation_shared import DOCUMENTATION__oauth_token, DOCUMENTATION__oauth_refresh
-
 DOCUMENTATION__is_alive = SwaggerDocumentation(
     security=False,
     tags="Is Alive",
@@ -134,14 +96,14 @@ DOCUMENTATION__is_alive = SwaggerDocumentation(
     )
 )
 
-DOCUMENTATION__deploy = SwaggerDocumentation(
-    tags="Deployment",
-    methods=[
-        SwaggerMethod(
-            name="Redeploys the JAAQL service",
-            description="Will redeploy the JAAQL service, loading the latest version from git. In the future will "
-                        "support loading a specific tagged version",
-            method=REST__POST
-        )
-    ]
+DOCUMENTATION__clean = SwaggerDocumentation(
+    tags="Installation",
+    methods=SwaggerMethod(
+        name="Clean database",
+        description="Will clear the database and leave jaaql installed",
+        method=REST__POST
+    )
 )
+
+# Not unused. Used to generate html files
+from jaaql.documentation.documentation_shared import DOCUMENTATION__oauth_token, DOCUMENTATION__oauth_refresh
