@@ -44,7 +44,7 @@ def bootup(vault_key, is_gunicorn: bool = False, install_on_bootup: bool = False
             "super_db_password": "passw0rd",
             "jaaql_password": "pa55word",
             "install_key": install_key,
-            "allow_uninstall": False
+            "allow_uninstall": True
         }
         if not is_gunicorn:
             json_data["db_connection_string"] = "postgresql://postgres:123456@localhost:5434/"
@@ -71,7 +71,7 @@ def bootup(vault_key, is_gunicorn: bool = False, install_on_bootup: bool = False
                 if i != 0:
                     print()
 
-                with open(join(script_root, script), "r") as script_file:
+                with open(join(script_root, script), "r", encoding="utf-8") as script_file:
                     print("Processing script " + script)
                     process_script(script_file.read(), base_url, bypass_header)
                 i += 1
